#
# spec file for package pkcs11-helper
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pkcs11-helper
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libgnutls-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  mozilla-nss-devel
BuildRequires:  pkg-config
Version:        1.11
Release:        4.4
Url:            https://github.com/OpenSC/OpenSC/wiki
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
License:        BSD-3-Clause and GPL-2.0
Group:          System/Libraries
Source:         https://github.com/OpenSC/pkcs11-helper/archive/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
Requires:       libpkcs11-helper1 = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# remove me when pkgconfig Libs.Private misbehaviours are fixed
Patch:          pkcs11-helper-1.06-pkgconfig.patch

%description
pkcs11-helper allows using multiple PKCS#11 providers at the same
   time and selecting keys by id, label or certificate subject.
   Besides it covers the following topics: * Handling card removal
   and card insert events

* Handling card re-insert to a different slot

* Supporting session expiration serialization

* and much more All this is possible using a simple API.

%package -n libpkcs11-helper1
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
Group:          System/Libraries

%description -n libpkcs11-helper1
pkcs11-helper allows using multiple PKCS#11 providers at the same time,
selecting keys by id, label or certificate subject, handling card
removal and card insert events, handling card re-insert to a different
slot, supporting session expiration serialization and much more, all
using a simple API.


%package devel
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libopenssl-devel

%description devel
pkcs11-helper allows using multiple PKCS#11 providers at the same time,
selecting keys by id, label or certificate subject, handling card
removal and card insert events, handling card re-insert to a different
slot, supporting session expiration serialization and much more, all
using a simple API.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch

%build
autoreconf -f -i
%configure --disable-static --with-pic\
	--enable-doc\
	--docdir=%{_docdir}/%{name}
make %{?jobs:-j%jobs}

%install
%makeinstall
cp -a AUTHORS ChangeLog THANKS $RPM_BUILD_ROOT%{_docdir}/%{name}/
%{__rm} -f %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}%{_docdir}

%post -n libpkcs11-helper1 -p /sbin/ldconfig

%postun -n libpkcs11-helper1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/api
%doc %{_mandir}/man8/*.*

%files -n libpkcs11-helper1
%defattr(-,root,root)
%{_libdir}/libpkcs11-helper.so.*

%files devel
%defattr(-,root,root)
%doc %{_docdir}/%{name}/api
%{_includedir}/pkcs11-helper-1.0
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/aclocal/*.m4

%changelog
* Sat Dec 20 2014 p.drouand@gmail.com
- Update to version 1.11
  + openssl: support generic pkey.
  + openssl: add dsa support.
  + openssl: add ecdsa support.
- Changes from version 1.10
  + PolarSSL crypto engine by Adriaan de Jong
  + build: --disable-crypto-engine-win32 renamed to
  - -disable-crypto-engine-cryptoapi
  + api: PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_WIN32 renamed to
    PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_CRYPTOAPI.
  + api: PKCS11H_ENGINE_CRYPTO_WIN32 renamed to
    PKCS11H_ENGINE_CRYPTO_CRYPTOAPI
- pkcs11-helper has a new home; update homepage and source Url
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Tue Jul 10 2012 sbrabec@suse.cz
- Update to version 1.09:
  * Do not retry if CKR_BUFFER_TOO_SMALL and none NULL target.
  * Do not attempt to logout if uninitialized.
  * Use OpenSSL engine's rsa_priv_enc instead of rsa_sign.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Apr  9 2009 sbrabec@suse.cz
- Updated to version 1.07:
  * Minor portability fix.
- Don't call autoreconf on older products.
* Wed Mar 18 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies and pkgconfig file
* Mon Sep  8 2008 sbrabec@suse.cz
- Updated to version 1.06:
  * Portability fixes.
* Tue Apr 15 2008 ro@suse.de
- added baselibs.conf file for multilib support
* Wed Apr  2 2008 sbrabec@suse.cz
- Updated to version 1.05:
  * Export pkcs11h_logout().
  * Added NSS crypto engine.
  * Added new slotevent mode (poll vs fetch).
  * Add more invalid characters to serialization string.
  * Fix openssl decrypt return code.
* Wed Aug  8 2007 sbrabec@suse.cz
- Fixed dependencies to allow to install more instances of library.
* Wed Aug  1 2007 sbrabec@suse.cz
- New SuSE package, version 1.03.
